Learn R Programming

GHRmodel (version 0.1.1)

dengue_MS: Dengue cases from the "Mato Grosso do Sul" state of Brazil

Description

The dengue_MS example data set contains monthly counts of notified dengue cases by microregion, along with a range of spatial and spatiotemporal covariates (e.g., environmental, socio-economic and meteo-climatic factors). This data set represents a subset of a larger national data set that covers the entire territory of Brazil. The subset focuses on a specific region, Mato Grosso do Sul, for the purposes of illustration and computational efficiency. See @source for access to the complete data set.

Usage

dengue_MS

Arguments

Format

A data frame with 2,600 rows and 27 columns:

micro_code

Unique ID number to each micro region (11 units)

micro_name

Name of each micro region

micro_name_ibge

Name of each micro region following IBGE

meso_code

Unique ID number to each meso region (4 units)

meso_name

Name of each meso region

state_code

Unique ID number to each state (1 unit)

state_name

Name of each state

region_code

Unique ID number given to each Brazilian Region, In this data frame all observations come from the "Southeast Region"

region_name

Name of each Brazilian Region, In this data frame all observations come from the "Southeast Region"

biome_code

Biome code

biome_name

Biome name

ecozone_code

Ecozone code

ecozone_name

Ecozone name

main_climate

Most prevalent climate regime in the microregion. Based on Koppen Geiger climate regimes

month

Calendar month index, 1 = January, 12 = December

year

Year 2000 - 2019

time

Time index starting at 1 for January 2000

dengue_cases

Number of notified dengue cases registered in the notifiable diseases system in Brazil (SINAN) in the microregion of reference, at the month of first symptoms

population

Estimated population, based on projections calculated using the 2000 and 2010 censuses, and counts taken in 2007 and 2017

pop_density

Population density (number of people per km2)

tmax

Monthly average daily maximum temperature; gridded values (at a 0.5 deg resolution) averaged across each microregion

tmin

Monthly average daily minimum temperature; gridded values (at a 0.5 deg resolution) averaged across each microregion

pdsi

Self-calibrated Palmer drought severity index for each microregion. It measures how wet or dry a region is relative to usual conditions. Negative values represent periods of drought, positive values represent wetter periods. Calculated by taking the mean value within each microregion

urban

Percentage of inhabitants living in urban areas (2010 census)

water_network

Percentage of inhabitants with access to the piped water network according to the 2010 census

water_shortage

Frequency of reported water shortages per microregion between 2000 - 2016

date

First day of the Month, in date format ("%d-%m-%Y")