Learn R Programming

GHRmodel (version 0.1.1)

dengue_SP: Dengue cases from the "São Paulo" state of Brazil

Description

The dengue_SP example data set reports the weekly number of notified dengue cases in the municipality of São Paulo together with climatic covariates. Data was sourced from Infodengue (see @source).

Usage

dengue_SP

Arguments

Format

A data frame with 678 rows and 8 columns:

date

First day of the week, in date format ("%d-%m-%Y")

geocode

Unique ID code for São Paulo microregion

cases

Number of notified dengue cases

year

Year 2000 - 2022

temp_med

Weekly average daily mean temperature

precip_tot

Weekly cumulative precipitation

enso

El Niño-Southern Oscillation Index

pop

Number of inhabitants