The dengue_MS example data set contains monthly counts of notified dengue cases by
microregion, along with a range of spatial and spatiotemporal covariates
(e.g., environmental, socio-economic and meteo-climatic factors).
This data set represents a subset of a larger national data set that covers
the entire territory of Brazil. The subset focuses on a specific region,
Mato Grosso do Sul, for the purposes of illustration and computational efficiency.
See @source for access to the complete data set.
dengue_MSA data frame with 2,600 rows and 27 columns:
micro_codeUnique ID number to each micro region (11 units)
micro_nameName of each micro region
micro_name_ibgeName of each micro region following IBGE
meso_codeUnique ID number to each meso region (4 units)
meso_nameName of each meso region
state_codeUnique ID number to each state (1 unit)
state_nameName of each state
region_codeUnique ID number given to each Brazilian Region, In this data frame all observations come from the "Southeast Region"
region_nameName of each Brazilian Region, In this data frame all observations come from the "Southeast Region"
biome_codeBiome code
biome_nameBiome name
ecozone_codeEcozone code
ecozone_nameEcozone name
main_climateMost prevalent climate regime in the microregion. Based on Koppen Geiger climate regimes
monthCalendar month index, 1 = January, 12 = December
yearYear 2000 - 2019
timeTime index starting at 1 for January 2000
dengue_casesNumber of notified dengue cases registered in the notifiable diseases system in Brazil (SINAN) in the microregion of reference, at the month of first symptoms
populationEstimated population, based on projections calculated using the 2000 and 2010 censuses, and counts taken in 2007 and 2017
pop_densityPopulation density (number of people per km2)
tmaxMonthly average daily maximum temperature; gridded values (at a 0.5 deg resolution) averaged across each microregion
tminMonthly average daily minimum temperature; gridded values (at a 0.5 deg resolution) averaged across each microregion
pdsiSelf-calibrated Palmer drought severity index for each microregion. It measures how wet or dry a region is relative to usual conditions. Negative values represent periods of drought, positive values represent wetter periods. Calculated by taking the mean value within each microregion
urbanPercentage of inhabitants living in urban areas (2010 census)
water_networkPercentage of inhabitants with access to the piped water network according to the 2010 census
water_shortageFrequency of reported water shortages per microregion between 2000 - 2016
dateFirst day of the Month, in date format ("%d-%m-%Y")