The dengue_SP example data set reports the weekly number of notified dengue cases in
the municipality of São Paulo together with climatic covariates. Data was sourced from
Infodengue (see @source).
dengue_SPA data frame with 678 rows and 8 columns:
dateFirst day of the week, in date format ("%d-%m-%Y")
geocodeUnique ID code for São Paulo microregion
casesNumber of notified dengue cases
yearYear 2000 - 2022
temp_medWeekly average daily mean temperature
precip_totWeekly cumulative precipitation
ensoEl Niño-Southern Oscillation Index
popNumber of inhabitants